@@ -8,12 +8,9 @@ Purpose: Get a prompt consisting Title and Transcript of a YouTube Video
 import argparse
 import sys
 
-from .utils import format_date, get_word_count
-from .prompts import (
-    REPLY_OK_IF_YOU_READ_TEMPLATE,
-    REPLY_OK_IF_YOU_READ_TEMPLATE_SPLITTED_FIRST,
-    REPLY_OK_IF_YOU_READ_TEMPLATE_SPLITTED_CONTINUED,
-)
+from . import __version__
+from .utils import deliver_prompts, format_date, get_word_count, deliver_prompts
+from .loaders import load_youtube_url
 
 
 def get_args():
@@ -25,6 +22,12 @@ def get_args():
     )
 
     parser.add_argument('youtube_url', metavar='YouTube URL', help='YouTube URL')
+    parser.add_argument(
+        '-V',
+        '--version',
+        action='version',
+        version=f'%(prog)s {__version__}',
+    )
     parser.add_argument(
         '-c', '--copy', help='Copy the prompt to clipboard', action='store_true'
     )
@@ -51,6 +54,8 @@ def get_args():
         default=2000,
     )
 
+    parser.add_argument('-n', '--dry-run', help='Dry run', action='store_true')
+
     args = parser.parse_args()
     args.youtube_url = args.youtube_url.split('&')[0]
     return args
@@ -60,12 +65,8 @@ def main():
     """Make a jazz noise here"""
 
     args = get_args()
-    from langchain.document_loaders import YoutubeLoader
-    from langchain.prompts import PromptTemplate
-
-    loader = YoutubeLoader.from_youtube_channel(args.youtube_url, add_video_info=True)
-    print(f'Loading transcript from {args.youtube_url}...', file=sys.stderr)
-    docs = loader.load()
+    print(f'Loading transcript from {args.youtube_url} ...', file=sys.stderr)
+    docs = load_youtube_url(args.youtube_url)
     print(
         f'Loaded transcript. Word count: {get_word_count((t := docs[0].page_content))} Char count: {len(t)}',
         file=sys.stderr,
@@ -83,46 +84,15 @@ def main():
         needs_splitting = True
     else:
         needs_splitting = False
-    if needs_splitting:
-        from langchain.text_splitter import TokenTextSplitter
-
-        splitter = TokenTextSplitter(encoding_name='cl100k_base', chunk_size=2000)
-        splitted = splitter.split_documents(docs)
-        num_chunks = len(splitted)
-        for i, doc in enumerate(splitted):
-            if i == 0:
-                prompt = PromptTemplate.from_template(
-                    REPLY_OK_IF_YOU_READ_TEMPLATE_SPLITTED_FIRST
-                )
-            else:
-                prompt = PromptTemplate.from_template(
-                    REPLY_OK_IF_YOU_READ_TEMPLATE_SPLITTED_CONTINUED
-                ).partial(x=str(i + 1))
-            content = doc.page_content
-            formatted_prompt = prompt.format(what=what, content=content)
-            input(
-                f'Press Enter to copy prompt {i+1}/{num_chunks}. Word Count: {get_word_count(formatted_prompt)}, Char count: {len(formatted_prompt)}: '
-            )
-            import pyperclip
-
-            pyperclip.copy(formatted_prompt)
-
-        return
-    transcript = docs[0].page_content
-    prompt = PromptTemplate.from_template(REPLY_OK_IF_YOU_READ_TEMPLATE)
-    content = transcript
-    formatted_prompt = prompt.format(what=what, content=content)
-    if args.copy:
-        import pyperclip
-
-        print(
-            f'Word Count: {get_word_count(formatted_prompt)}, Char count: {len(formatted_prompt)}',
-            file=sys.stderr,
-        )
-        pyperclip.copy(formatted_prompt)
-        print('Prompt copied to clipboard.', file=sys.stderr)
-    else:
-        print(formatted_prompt)
+    deliver_prompts(
+        what=what,
+        documents=docs,
+        should_be_only_one_doc=True,
+        needs_splitting=needs_splitting,
+        copy=args.copy,
+        chunk_size=args.chunk_size,
+        dry_run=args.dry_run,
+    )
 
 
 if __name__ == '__main__':
